pub struct BriefAction { /* private fields */ }Expand description
Brief action carried by the manager daily brief workflow; it assembles reviewable manager brief packets from deterministic context and agent drafts.
Implementations
Sourceimpl BriefAction
impl BriefAction
Sourcepub fn builder() -> BriefActionBuilder
pub fn builder() -> BriefActionBuilder
Create an instance of BriefAction using the builder syntax
Sourceimpl BriefAction
impl BriefAction
Sourcepub const fn id(&self) -> &ActionId
pub const fn id(&self) -> &ActionId
Returns the id source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn kind(&self) -> BriefActionKind
pub const fn kind(&self) -> BriefActionKind
Returns the kind source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn priority(&self) -> BriefActionPriority
pub const fn priority(&self) -> BriefActionPriority
Returns the priority source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn owner_persona(&self) -> ManagerBriefPersona
pub const fn owner_persona(&self) -> ManagerBriefPersona
Returns the owner persona source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn removed_manual_work(&self) -> RemovedManualWork
pub const fn removed_manual_work(&self) -> RemovedManualWork
Returns the removed manual work source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn rationale(&self) -> &ActionRationale
pub const fn rationale(&self) -> &ActionRationale
Returns the rationale source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn source_facts(&self) -> &[SourceFact]
pub fn source_facts(&self) -> &[SourceFact]
Returns the source facts source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn labor_impact(&self) -> &LaborImpactEstimate
pub const fn labor_impact(&self) -> &LaborImpactEstimate
Returns the labor impact source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn required_review_gates(&self) -> &[ReviewGate]
pub fn required_review_gates(&self) -> &[ReviewGate]
Returns the required review gates source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn is_source_grounded(&self) -> bool
pub fn is_source_grounded(&self) -> bool
Reports whether the manager daily brief workflow satisfies the is source grounded safety condition.