pub struct Packet { /* private fields */ }Expand description
Reviewable packet handed to staff or agents with deterministic gates already applied.
Implementations
Sourceimpl Packet
impl Packet
Sourcepub const fn location_id(&self) -> LocationId
pub const fn location_id(&self) -> LocationId
Returns the location id source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn operating_day(&self) -> Date
pub const fn operating_day(&self) -> Date
Returns the operating day source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn prepared_for(&self) -> ManagerBriefPersona
pub const fn prepared_for(&self) -> ManagerBriefPersona
Returns the prepared for source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn actions(&self) -> &[BriefAction]
pub fn actions(&self) -> &[BriefAction]
Returns the actions source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn safe_agent_actions(&self) -> &[SafeAgentAction]
pub fn safe_agent_actions(&self) -> &[SafeAgentAction]
Returns the safe agent actions source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn blocked_actions(&self) -> &[BlockedAction]
pub fn blocked_actions(&self) -> &[BlockedAction]
Returns the blocked actions source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn before_minutes(&self) -> AggregateLaborMinutes
pub const fn before_minutes(&self) -> AggregateLaborMinutes
Returns the before minutes source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn after_minutes(&self) -> AggregateLaborMinutes
pub const fn after_minutes(&self) -> AggregateLaborMinutes
Returns the after minutes source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn minutes_saved(&self) -> u16
pub const fn minutes_saved(&self) -> u16
Returns the minutes saved source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn all_actions_are_source_grounded(&self) -> bool
pub fn all_actions_are_source_grounded(&self) -> bool
Returns the all actions are source grounded source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.