Request

Struct Request 

pub struct Request { /* private fields */ }
Input contract for building the workflow packet from source-grounded records.

Implementations

Source

impl Request

pub fn builder() -> RequestBuilder

Create an instance of Request using the builder syntax

Source

impl Request

pub const fn location_id(&self) -> LocationId

Returns the location id source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn operating_day(&self) -> Date

Returns the operating day source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn prepared_for(&self) -> ManagerBriefPersona

Returns the prepared for source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn demand_attention_threshold(&self) -> DemandThresholdUnits

Returns the demand attention threshold source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.

pub fn service_demand_facts(&self) -> &[Fact]

Returns the service demand facts source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.

pub fn checkout_packets(&self) -> &[ScopedCheckoutPacket]

Returns the checkout packets source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.

pub fn retention_packets(&self) -> &[ScopedRetentionPacket]

Returns the retention packets source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.