ScopedRetentionPacket

Struct ScopedRetentionPacket 

pub struct ScopedRetentionPacket { /* private fields */ }
Scoped retention packet carried by the manager daily brief workflow; it assembles reviewable manager brief packets from deterministic context and agent drafts.

Implementations

Source

impl ScopedRetentionPacket

pub fn builder() -> ScopedRetentionPacketBuilder

Create an instance of ScopedRetentionPacket using the builder syntax

Source

impl ScopedRetentionPacket

pub const fn location_id(&self) -> LocationId

Returns the location id source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn operating_day(&self) -> Date

Returns the operating day source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn packet(&self) -> &Packet

Returns the packet source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.