pub struct SourceFact { /* private fields */ }Expand description
Source fact used by the manager daily brief workflow; it assembles reviewable manager brief packets from deterministic context and agent drafts.
Implementations
Sourceimpl SourceFact
impl SourceFact
Sourcepub fn builder() -> SourceFactBuilder
pub fn builder() -> SourceFactBuilder
Create an instance of SourceFact using the builder syntax
Sourceimpl SourceFact
impl SourceFact
Sourcepub const fn kind(&self) -> SourceFactKind
pub const fn kind(&self) -> SourceFactKind
Returns the kind evidence available to manager daily brief review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn summary(&self) -> &BriefSummary
pub const fn summary(&self) -> &BriefSummary
Returns the summary evidence available to manager daily brief review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn source_record_refs(&self) -> &[RecordRef]
pub fn source_record_refs(&self) -> &[RecordRef]
Returns the source record refs evidence available to manager daily brief review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn has_source_evidence(&self) -> bool
pub fn has_source_evidence(&self) -> bool
Reports whether the manager daily brief workflow satisfies the has source evidence safety condition.