pub struct LaborImpactEstimate { /* private fields */ }Expand description
Labor impact estimate carried by the manager daily brief workflow; it assembles reviewable manager brief packets from deterministic context and agent drafts.
Implementations
Sourceimpl LaborImpactEstimate
impl LaborImpactEstimate
Sourcepub const fn new(
before_minutes: LaborMinutes,
after_minutes: LaborMinutes,
) -> Self
pub const fn new( before_minutes: LaborMinutes, after_minutes: LaborMinutes, ) -> Self
Builds new for the manager daily brief workflow contract from validated source facts while preserving review gates and draft-only side-effect boundaries.
Sourcepub const fn before_minutes(&self) -> LaborMinutes
pub const fn before_minutes(&self) -> LaborMinutes
Returns the before minutes source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn after_minutes(&self) -> LaborMinutes
pub const fn after_minutes(&self) -> LaborMinutes
Returns the after minutes source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn minutes_saved(&self) -> u16
pub const fn minutes_saved(&self) -> u16
Returns the minutes saved source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.