pub struct OutcomeRecord { /* private fields */ }Expand description
Outcome record carried by the manager daily brief workflow; it assembles reviewable manager brief packets from deterministic context and agent drafts.
Implementations
Sourceimpl OutcomeRecord
impl OutcomeRecord
Sourcepub fn builder() -> OutcomeRecordBuilder
pub fn builder() -> OutcomeRecordBuilder
Create an instance of OutcomeRecord using the builder syntax
Sourceimpl OutcomeRecord
impl OutcomeRecord
Sourcepub const fn action_id(&self) -> &ActionId
pub const fn action_id(&self) -> &ActionId
Returns the action id source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn recorded_by(&self) -> &ActorRef
pub const fn recorded_by(&self) -> &ActorRef
Returns the recorded by source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn outcome(&self) -> FeedbackOutcome
pub const fn outcome(&self) -> FeedbackOutcome
Returns the outcome source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn before_minutes(&self) -> LaborMinutes
pub const fn before_minutes(&self) -> LaborMinutes
Returns the before minutes source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn actual_minutes(&self) -> LaborMinutes
pub const fn actual_minutes(&self) -> LaborMinutes
Returns the actual minutes source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn actual_minutes_saved(&self) -> u16
pub const fn actual_minutes_saved(&self) -> u16
Returns the actual minutes saved source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn source_record_refs(&self) -> &[RecordRef]
pub fn source_record_refs(&self) -> &[RecordRef]
Returns the source record refs source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn records_feedback_without_external_mutation(&self) -> bool
pub fn records_feedback_without_external_mutation(&self) -> bool
Returns the records feedback without external mutation source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn blocked_actions(&self) -> Vec<BlockedAction>
pub fn blocked_actions(&self) -> Vec<BlockedAction>
Returns the blocked actions source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.