pub struct Request { /* private fields */ }Expand description
Input contract for building the workflow packet from source-grounded records.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> RequestBuilder
pub fn builder() -> RequestBuilder
Create an instance of Request using the builder syntax
Sourceimpl Request
impl Request
Sourcepub const fn location_id(&self) -> LocationId
pub const fn location_id(&self) -> LocationId
Returns the location id source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn operating_day(&self) -> Date
pub const fn operating_day(&self) -> Date
Returns the operating day source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn prepared_for(&self) -> ManagerBriefPersona
pub const fn prepared_for(&self) -> ManagerBriefPersona
Returns the prepared for source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn demand_attention_threshold(&self) -> DemandThresholdUnits
pub const fn demand_attention_threshold(&self) -> DemandThresholdUnits
Returns the demand attention threshold source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn service_demand_facts(&self) -> &[Fact]
pub fn service_demand_facts(&self) -> &[Fact]
Returns the service demand facts source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn checkout_packets(&self) -> &[ScopedCheckoutPacket]
pub fn checkout_packets(&self) -> &[ScopedCheckoutPacket]
Returns the checkout packets source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn retention_packets(&self) -> &[ScopedRetentionPacket]
pub fn retention_packets(&self) -> &[ScopedRetentionPacket]
Returns the retention packets source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.