pub struct ScopedCheckoutPacket { /* private fields */ }Expand description
Scoped checkout packet carried by the manager daily brief workflow; it assembles reviewable manager brief packets from deterministic context and agent drafts.
Implementations
Sourceimpl ScopedCheckoutPacket
impl ScopedCheckoutPacket
Sourcepub fn builder() -> ScopedCheckoutPacketBuilder
pub fn builder() -> ScopedCheckoutPacketBuilder
Create an instance of ScopedCheckoutPacket using the builder syntax
Sourceimpl ScopedCheckoutPacket
impl ScopedCheckoutPacket
Sourcepub const fn location_id(&self) -> LocationId
pub const fn location_id(&self) -> LocationId
Returns the location id source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn operating_day(&self) -> Date
pub const fn operating_day(&self) -> Date
Returns the operating day source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.