pub struct ScopedRetentionPacket { /* private fields */ }Expand description
Scoped retention packet carried by the manager daily brief workflow; it assembles reviewable manager brief packets from deterministic context and agent drafts.
Implementations
Sourceimpl ScopedRetentionPacket
impl ScopedRetentionPacket
Sourcepub fn builder() -> ScopedRetentionPacketBuilder
pub fn builder() -> ScopedRetentionPacketBuilder
Create an instance of ScopedRetentionPacket using the builder syntax
Sourceimpl ScopedRetentionPacket
impl ScopedRetentionPacket
Sourcepub const fn location_id(&self) -> LocationId
pub const fn location_id(&self) -> LocationId
Returns the location id source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn operating_day(&self) -> Date
pub const fn operating_day(&self) -> Date
Returns the operating day source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.