pub struct SourceFact { /* private fields */ }Expand description
Source fact carried by the manager daily brief workflow; it assembles reviewable manager brief packets from deterministic context and agent drafts.
Implementations
Sourceimpl SourceFact
impl SourceFact
Sourcepub fn builder() -> SourceFactBuilder
pub fn builder() -> SourceFactBuilder
Create an instance of SourceFact using the builder syntax
Sourceimpl SourceFact
impl SourceFact
Sourcepub const fn kind(&self) -> SourceFactKind
pub const fn kind(&self) -> SourceFactKind
Returns the kind source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn summary(&self) -> &BriefSummary
pub const fn summary(&self) -> &BriefSummary
Returns the summary source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn source_record_refs(&self) -> &[RecordRef]
pub fn source_record_refs(&self) -> &[RecordRef]
Returns the source record refs source evidence carried by this manager daily brief workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn has_source_evidence(&self) -> bool
pub fn has_source_evidence(&self) -> bool
Reports whether the manager daily brief workflow satisfies the has source evidence safety condition.